pub struct IndexSubtable2<'a> {
data: FontData<'a>,
}Expand description
IndexSubTable2: all glyphs have identical metrics.
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> IndexSubtable2<'a>
impl<'a> IndexSubtable2<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn index_format(&self) -> u16
pub fn index_format(&self) -> u16
Format of this IndexSubTable.
Sourcepub fn image_format(&self) -> u16
pub fn image_format(&self) -> u16
Format of EBDT image data.
Sourcepub fn image_data_offset(&self) -> u32
pub fn image_data_offset(&self) -> u32
Offset to image data in EBDT table.
Sourcepub fn image_size(&self) -> u32
pub fn image_size(&self) -> u32
All the glyphs are of the same size.
Sourcepub fn big_metrics(&self) -> &'a [BigGlyphMetrics]
pub fn big_metrics(&self) -> &'a [BigGlyphMetrics]
All glyphs have the same metrics; glyph data may be compressed, byte-aligned, or bit-aligned.
pub fn index_format_byte_range(&self) -> Range<usize> ⓘ
pub fn image_format_byte_range(&self) -> Range<usize> ⓘ
pub fn image_data_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn image_size_byte_range(&self) -> Range<usize> ⓘ
pub fn big_metrics_byte_range(&self) -> Range<usize> ⓘ